@@ -6,7 +6,7 @@ from dapla.services.writer import DataSourceWriter
 from dapla.services.clients import DatasetDocClient
 
 
-def read_pandas(path, columns=None):
+def read_pandas(path, columns=None, **kwargs):
     """
     Read Parquet data from a path in Dapla.
 
@@ -16,7 +16,10 @@ def read_pandas(path, columns=None):
         A path that will be mapped to a GCS path in Dapla
     columns : List[str], optional
         Subset of columns to read.
-
+    kwargs: dict
+            Passed to pyarrow.Table.to_pandas, see
+            https://arrow.apache.org/docs/python/generated/pyarrow.Table.html#pyarrow.Table.to_pandas
+            For example, ``{'categories': ['column_1']}``
     Returns
     -------
     pyarrow.Table
@@ -24,7 +27,7 @@ def read_pandas(path, columns=None):
     """
     reader = DataSourceReader(AuthClient.get_access_token, os.environ['DATA_ACCESS_URL'],  os.environ['CATALOG_URL'])
     try:
-        return reader.read(path, columns)
+        return reader.read(path, columns, **kwargs)
     except AuthError as err:
         err.print_warning()
 
